@@ -1,7 +1,7 @@
 import json
 import os
 import re
-from os.path import exists, join, abspath, isdir, basename, dirname, relpath
+from os.path import exists, join, abspath, isdir, basename, dirname, relpath, isfile
 from shutil import ignore_patterns
 
 import inquirer
@@ -125,6 +125,7 @@ class InitCommand(Command):
             settings['guniflask_max_version'] = f'{version_info[0]}.{int(version_info[1]) + 1}'
         else:
             settings['guniflask_max_version'] = f'{int(version_info[0]) + 1}.0'
+        self.infer_project_version(project_dir, settings)
 
         self.print_copying_files()
         self.force = False
@@ -135,6 +136,20 @@ class InitCommand(Command):
         print(flush=True)
         self.print_success()
 
+    def infer_project_version(self, project_dir, settings):
+        project_name = settings['project_name']
+        p = join(project_dir, project_name, '__init__.py')
+        if isfile(p):
+            with open(p, 'r', encoding='utf-8') as f:
+                s = re.search(r"__version__ = '([^']+)'", f.read())
+        else:
+            s = None
+        if s:
+            version = s.group(1)
+        else:
+            version = '0.0.0'
+        settings['project_version'] = version
+
     def resolve_ignore_files(self, settings):
         ignore_files = set()
         project_name = settings['project_name']
@@ -226,13 +241,13 @@ class InitCommand(Command):
 
     @staticmethod
     def print_welcome(project_dir):
-        print(f'\033[37mWelcome to guniflask-cli generator\033[0m \033[33mv{__version__}\033[0m', flush=True)
-        print(f'\033[37mApplication file will be created in folder:\033[0m \033[33m{project_dir}\033[0m', flush=True)
+        print(f'\033[37mWelcome to guniflask generator\033[0m \033[33mv{__version__}\033[0m', flush=True)
+        print(f'\033[37mApplication files will be created in folder:\033[0m \033[33m{project_dir}\033[0m', flush=True)
 
     @staticmethod
     def print_regenerate_project():
         print('\033[32mThis is an existing project, using the configuration from .guniflask-init.json '
-              'to regenerate the project...\033[0m')
+              'to regenerate the project...\033[0m', flush=True)
 
     @staticmethod
     def print_success():
